==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Nu s-a putut încărca jocul precedent. Un joc nou va fi pornit.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 scurs</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 mutări făcute</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 din %2 obiective rămase</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>În pauză</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Fereastră</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comandă</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opţiuni</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Vînează şi omoară</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker recursiv</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stivă</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stivă 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stivă 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stivă 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stivă 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritm:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Obiective:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Mărime:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Vînează şi omoară</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker recursiv</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stivă</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stivă 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stivă 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stivă 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stivă 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Scoruri CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Timp</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Paşi</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritm</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Mărime</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Scorul dvs. a intrat în top 10.
Vă rugăm tastaţi numele dvs.:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Joc</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Arată unde aţi fost</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Arată numărul de mutări făcute</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Arată timpul scurs</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Mişcări line</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controale</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Mută în sus:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Mută în jos:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Mută la stînga:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Mută la dreapta:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Comutare steguleţ:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teme</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adaugă</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Elimină</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Selectaţi fişierul temă</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nu s-a putut crea folder-ul datelor.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nu s-a putut copia fişierul temă.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Eliminaţi tema selectată?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Nu s-a putut elimina tema selectată.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vizualizare</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>Indiciu</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Scoruri &amp;record</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Mărire</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>M&amp;icşorare</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferinţe...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Un joc labirint sus-jos</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Icon-urile sînt din tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Folosit sub licenţă &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.4.orig.tar.gz: cutemaze-1.2.4/translations/cutemaze_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Nu s-a putut încărca jocul precedent. Un joc nou va fi pornit.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 scurs</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 mutări făcute</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 din %2 obiective rămase</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>În pauză</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Fereastră</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comandă</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opţiuni</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Vînează şi omoară</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker recursiv</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stivă</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stivă 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stivă 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stivă 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stivă 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritm:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Obiective:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Mărime:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Vînează şi omoară</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Backtracker recursiv</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stivă</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stivă 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stivă 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stivă 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stivă 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Scoruri CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Scor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Timp</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Paşi</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritm</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Mărime</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Felicitări!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Scorul dvs. a intrat în top 10.
Vă rugăm tastaţi numele dvs.:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Joc</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Arată unde aţi fost</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Arată numărul de mutări făcute</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Arată timpul scurs</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Mişcări line</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controale</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Mută în sus:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Mută în jos:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Mută la stînga:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Mută la dreapta:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Comutare steguleţ:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teme</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adaugă</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Elimină</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Selectaţi fişierul temă</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nu s-a putut crea folder-ul datelor.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nu s-a putut copia fişierul temă.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Eliminaţi tema selectată?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Nu s-a putut elimina tema selectată.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Arată indiciu:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vizualizare</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauză</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>Indiciu</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Scoruri &amp;record</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Mărire</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>M&amp;icşorare</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Limbă aplicaţie...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferinţe...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Un joc labirint sus-jos</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Icon-urile sînt din tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Folosit sub licenţă &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
